# Product Requirements Document (PRD) : Emploi'IA

**Version :** 1.0
**Date :** 11 juin 2025
**Auteur :** [Votre Nom/Équipe]
**Nom du Produit :** Emploi'IA (ou le nom final choisi)

---

## 1. Introduction

### 1.1. Vision du Produit

Emploi'IA est une plateforme web innovante et intelligente, conçue pour transformer l'expérience de recherche d'emploi et d'évolution professionnelle en France. En s'appuyant sur l'intelligence artificielle et l'intégration profonde des données officielles de France Travail (anciennement Pôle Emploi) et de partenaires spécialisés, Emploi'IA vise à offrir aux demandeurs d'emploi et aux professionnels en transition une expérience personnalisée, pertinente et proactive. Notre objectif est de simplifier les démarches, de fournir des insights précis sur le marché du travail et d'offrir des parcours de carrière sur mesure.

### 1.2. Objectifs du Produit

* **Simplifier la Recherche d'Emploi :** Réduire le temps et l'effort nécessaires pour trouver des offres pertinentes.
* **Augmenter la Pertinence :** Fournir des matchs emploi-profil de haute qualité grâce à l'IA et aux référentiels ROME.
* **Autonomiser les Utilisateurs :** Offrir des outils et des informations pour une meilleure compréhension du marché du travail et une prise de décision éclairée.
* **Personnaliser l'Expérience :** Adapter les suggestions (offres, formations, événements) aux besoins et compétences spécifiques de chaque utilisateur.
* **Fiabilité des Données :** Utiliser exclusivement des APIs officielles et fiables pour garantir la qualité de l'information.
* **Adoption Utilisateur (KPI) :** Atteindre X utilisateurs actifs mensuels après 6 mois post-MVP.
* **Satisfaction Utilisateur (KPI) :** Obtenir un score NPS (Net Promoter Score) de X% ou plus.

### 1.3. Public Cible / Personas

Emploi'IA cible principalement :

* **Les Demandeurs d'Emploi Actifs :** Personnes à la recherche d'un nouveau poste, qu'elles soient en situation de chômage ou en transition.
    * **Besoin :** Trouver rapidement des offres pertinentes, comprendre les exigences des postes, optimiser leur candidature.
* **Les Professionnels en Évolution / Reconversion :** Individus souhaitant changer de métier, monter en compétences ou explorer de nouvelles opportunités.
    * **Besoin :** Identifier les métiers porteurs, les formations adaptées, comprendre les passerelles entre métiers, évaluer les compétences transférables.
* **Les Jeunes Diplômés / Entrants sur le Marché du Travail :** Cherchant un premier emploi ou une première orientation.
    * **Besoin :** Comprendre le marché, identifier les compétences clés pour un métier, trouver des stages ou des formations.

### 1.4. Contexte et Problème Résolu

La recherche d'emploi en France peut être complexe, longue et démotivante. Les outils existants sont souvent génériques, manquent de personnalisation ou ne fournissent pas une vision complète du marché. Les informations sont dispersées (offres, formations, statistiques). Les demandeurs ont du mal à identifier leurs compétences réelles et celles à développer, ou à cibler les entreprises qui recrutent réellement.

Emploi'IA résout ces problèmes en :
* Centralisant les informations pertinentes.
* Appliquant l'IA pour un matching précis et des insights intelligents.
* Offrant une expérience utilisateur fluide et intuitive, inspirée des meilleures pratiques du marché (ex: Google Careers).

---

## 2. Aperçu des Fonctionnalités (par Phase)

Cette section fournit un aperçu de haut niveau des fonctionnalités, détaillées ensuite.

### 2.1. Phase 1 : MVP (Minimum Viable Product)

* **Objectif :** Lancer une plateforme fonctionnelle de base pour la recherche d'offres et un matching IA simple.
* **Fonctionnalités Clés :** Authentification utilisateur, profil basique (métiers/compétences ROME), recherche d'offres d'emploi, matching IA simple (texte libre -> ROME), affichage détaillé des offres, ajout aux favoris, redirection pour postuler, génération simple de LM.

### 2.2. Phase 2 : Enrichissement & Personnalisation Approfondie

* **Objectif :** Intégrer les fonctionnalités d'IA avancées, l'analyse de données marché, et des outils de guidance de carrière.
* **Fonctionnalités Clés :** Intégration SSO France Travail, profil avancé (analyse CV, compétences graphiques), matching enrichi (soft skills, situations de travail), tableaux de bord marché, suggestions de formations/entreprises, fiches métiers complètes, outils de candidature avancés.

### 2.3. Phase 3 et au-delà : Excellence Opérationnelle & Nouveaux Services

* **Objectif :** Optimisation continue, IA proactive, événements personnalisés et expansion de l'écosystème.
* **Fonctionnalités Clés :** Notifications proactives (événements, rappels), coaching IA continu, outils de négociation salariale, potentiel de réseautage, analyse de trajectoire professionnelle.

---

## 3. Exigences Fonctionnelles Détaillées (Focus sur le MVP)

### 3.1. Gestion Utilisateur

* **Description :** Permettre aux utilisateurs de s'inscrire, se connecter et gérer un profil de base sur Emploi'IA.
* **User Stories :**
    * `En tant qu'utilisateur non enregistré, je veux pouvoir m'inscrire avec mon email et un mot de passe afin d'accéder aux fonctionnalités de la plateforme.`
    * `En tant qu'utilisateur enregistré, je veux pouvoir me connecter avec mon email et mon mot de passe afin de reprendre ma session.`
    * `En tant qu'utilisateur, je veux pouvoir renseigner mon nom, ma localisation, mon métier recherché et mes compétences clés afin de commencer à personnaliser mon profil.`
    * `En tant qu'utilisateur, je veux que mes saisies de métier et compétences soient aidées par des suggestions pour un mapping ROME initial.`
* **Dépendances APIs :** `ROME 4.0 - Métiers`, `ROME 4.0 - Compétences`, `Romeo` (pour l'aide à la complétion/suggestion ROME).

### 3.2. Recherche d'Offres d'Emploi

* **Description :** Offrir une interface de recherche intuitive et performante pour trouver des offres d'emploi.
* **User Stories :**
    * `En tant qu'utilisateur, je veux pouvoir rechercher des offres d'emploi par mots-clés et localisation afin de trouver des postes qui m'intéressent.`
    * `En tant qu'utilisateur, je veux pouvoir filtrer les résultats par type de contrat (CDI, CDD, Intérim...) et date de publication afin d'affiner ma recherche.`
    * `En tant qu'utilisateur, je veux voir une liste claire et paginée des offres pertinentes avec les informations essentielles.`
* **Dépendances APIs :** `Offres d'emploi`.

### 3.3. Matching IA Basique

* **Description :** Utiliser l'IA pour associer intelligemment le profil de l'utilisateur avec les offres d'emploi.
* **User Stories :**
    * `En tant qu'utilisateur, je veux que la plateforme analyse les offres d'emploi pour identifier les métiers et compétences ROME automatiquement.`
    * `En tant qu'utilisateur, je veux voir un indicateur de pertinence (score ou badge) sur chaque offre, montrant à quel point elle correspond à mon profil.`
* **Dépendances APIs :** `Romeo`, `ROME 4.0 - Métiers`, `ROME 4.0 - Compétences`.

### 3.4. Consultation et Actions sur une Offre

* **Description :** Permettre à l'utilisateur de consulter les détails d'une offre et d'effectuer des actions (favoris, candidature).
* **User Stories :**
    * `En tant qu'utilisateur, je veux pouvoir cliquer sur une offre pour voir sa description complète et ses informations détaillées.`
    * `En tant qu'utilisateur, je veux pouvoir ajouter une offre à mes favoris pour la retrouver facilement plus tard.`
    * `En tant qu'utilisateur, je veux pouvoir générer une lettre de motivation simple pour l'offre sélectionnée, pré-remplie avec mes informations et celles de l'offre.`
    * `En tant qu'utilisateur, je veux pouvoir cliquer sur un bouton pour postuler à l'offre, qui me redirige vers le site de candidature externe.`
* **Dépendances APIs :** `Offres d'emploi` (pour le détail).

---

## 4. Intégrations APIs (Récapitulatif et Cas d'Usage)

Emploi'IA s'appuiera sur les APIs suivantes, avec une authentification OAuth2 (Client Credentials Flow pour les APIs de données, et ultérieurement Authorization Code Flow pour le SSO Utilisateur) :

| API (Fournisseur)             | Rôle Principal pour Emploi'IA                                    | Cas d'Usage Majeurs                                                                                              | Phase d'Intégration |
| :---------------------------- | :--------------------------------------------------------------- | :--------------------------------------------------------------------------------------------------------------- | :------------------ |
| `Offres d'emploi` (FT)        | Source principale des offres d'emploi.                           | Recherche d'offres, affichage des détails, filtres.                                                              | MVP (Phase 1)       |
| `ROME 4.0 - Métiers` (FT)     | Référentiel des métiers ROME.                                    | Synchronisation initiale, validation des métiers, interprétation des codes ROME de `Romeo`.                      | MVP (Phase 1)       |
| `ROME 4.0 - Compétences` (FT) | Référentiel des compétences ROME.                                | Synchronisation initiale, validation des compétences, interprétation des codes ROME de `Romeo`.                 | MVP (Phase 1)       |
| `Romeo` (FT)                  | Moteur d'IA pour le mapping texte libre <-> ROME.                | Analyse des offres d'emploi, aide à la saisie du profil, analyse de CV.                                         | MVP (Phase 1)       |
| `API SSO France Travail` (FT) | Authentification utilisateur déléguée.                           | Connexion simplifiée via identifiants FT, potentiel d'enrichissement du profil.                                  | Phase 2             |
| `Match via Soft Skills` (Instarlink) | Intégration des soft skills dans le matching.                    | Affinage du matching, suggestions de soft skills à développer.                                                    | Phase 2             |
| `ROME V4.0 - Situations de travail` (FT) | Référentiel des environnements de travail.                     | Préférences utilisateur sur le contexte de travail, affinage du matching.                                        | Phase 2             |
| `ROME V4.0 - Fiches ROME` (FT) | Fiches métiers structurées.                                      | Pages détaillées sur les métiers, passerelles de carrière.                                                        | Phase 2             |
| `La Bonne Boîte` (FT)         | Identification d'entreprises qui recrutent.                      | Aide à la candidature spontanée ciblée.                                                                          | Phase 2             |
| `Marché du travail` (FT)      | Statistiques sur l'emploi et les tensions.                       | Tableaux de bord, conseils sur les métiers porteurs, données localisées.                                         | Phase 2             |
| `Open formation` (FT)         | Accès aux offres de formation.                                   | Suggestions de formations personnalisées.                                                                        | Phase 2             |
| `Sortants de formation et accès à l'emploi` (FT) | Statistiques sur le succès des formations.                         | Validation de la pertinence des formations suggérées.                                                            | Phase 2             |
| `Mes évènements France Travail` (FT) | Événements emploi/formation locaux.                                | Notifications et suggestions d'événements pertinents.                                                            | Phase 3+            |

---

## 5. Exigences Non-Fonctionnelles

### 5.1. Performance

* **Temps de Réponse :**
    * Moins de 2 secondes pour les requêtes de recherche d'offres et l'affichage des détails (90ème percentile).
    * Moins de 500 ms pour les requêtes API internes critiques (authentification, accès profil).
* **Scalabilité :** La plateforme doit pouvoir supporter une augmentation significative du nombre d'utilisateurs (jusqu'à X utilisateurs simultanés en Phase 2) et de requêtes sans dégradation majeure des performances.
* **Temps de Synchronisation ROME :** Les mises à jour des référentiels ROME ne doivent pas impacter la disponibilité de la plateforme.

### 5.2. Sécurité

* **Authentification et Autorisation :** Implémentation sécurisée des processus d'inscription/connexion et de gestion des accès (hachage des mots de passe, tokens JWT sécurisés).
* **Protection des Données Personnelles (RGPD) :**
    * Collecte et traitement des données conformes au RGPD (consentement explicite, droit à l'oubli, droit à la rectification).
    * Stockage des données sensibles (CV, informations profil détaillées) chiffré.
    * Audit régulier des vulnérabilités de sécurité.
* **Sécurité API :** Gestion sécurisée des clés API et des tokens OAuth2 pour les interactions avec France Travail.

### 5.3. UI/UX (Design)

* **Inspiration :** Fortement inspiré par les principes de design de **Google Careers** (simplicité, clarté, recherche puissante, hiérarchie de l'information).
* **Intuitivité :** La navigation et l'utilisation de la plateforme doivent être faciles et naturelles pour l'utilisateur, même sans formation.
* **Transparence de l'IA :** L'intelligence artificielle doit être perçue comme un assistant utile et non comme une "boîte noire". Les scores de matching, les suggestions et les analyses doivent être présentés de manière compréhensible et non intrusive.
* **Responsivité :** La plateforme doit être pleinement fonctionnelle et optimisée pour une utilisation sur tous les types d'appareils (desktop, tablette, mobile).
* **Accessibilité :** Conformité aux normes d'accessibilité web (RGAA ou WCAG) pour garantir l'utilisation par tous.
* **Feedback Visuel :** Des indicateurs clairs et immédiats sur les actions de l'utilisateur et l'état du système.

### 5.4. Fiabilité et Disponibilité

* **Uptime :** Objectif de disponibilité de 99.5% pour les services critiques du MVP, augmentant à 99.9% pour les phases ultérieures.
* **Gestion des Erreurs :** Robustesse face aux erreurs API externes (France Travail, Instarlink) avec des messages d'erreur clairs pour l'utilisateur et des mécanismes de retry/fallback côté backend.
* **Cohérence des Données :** Assurer la cohérence des données ROME et des offres d'emploi synchronisées.

### 5.5. Maintenabilité

* **Qualité du Code :** Code propre, bien commenté, respectant les bonnes pratiques de développement.
* **Documentation Technique :** Documentation API interne, architecture, guides de déploiement.
* **Facilité d'Évolution :** Architecture modulaire permettant d'ajouter de nouvelles fonctionnalités et APIs sans refonte majeure.

### 5.6. Monitoring & Logging

* Mise en place d'outils de monitoring des performances applicatives (APM), des logs centralisés et des alertes pour détecter et résoudre rapidement les problèmes.
* Suivi des appels aux APIs externes (succès/échecs, temps de réponse).

---

## 6. Considérations Techniques et Architecture (Haut Niveau)

* **Stack Technologique (Exemple) :**
    * **Backend :** Python (Django/FastAPI) ou Node.js (Express)
    * **Base de Données :** PostgreSQL (pour sa robustesse et sa gestion JSON pour les données semi-structurées de ROME)
    * **Frontend :** React ou Vue.js (pour une expérience utilisateur riche et dynamique)
* **Architecture :**
    * **MVP :** Approche "monolithe modulaire" possible pour accélérer le développement, avec des modules bien séparés pour les utilisateurs, les offres, et les intégrations ROME.
    * **Phases Ultérieures :** Évolution vers une architecture micro-services pour les composants critiques (ex: service de matching IA, service de profil) pour une meilleure scalabilité et indépendance.
    * **API Gateway :** Point d'entrée unique pour les requêtes frontend vers le backend, gérant l'authentification, les redirections.
* **Stratégie de Base de Données :**
    * Stockage des utilisateurs, de leurs profils.
    * Cache des offres d'emploi pertinentes et des données ROME pour optimiser les performances et réduire les appels API externes.
* **Stratégie de Déploiement :**
    * Utilisation d'un fournisseur Cloud (ex: AWS, GCP, Azure, OVH) avec des services managés pour réduire la charge opérationnelle.
    * Conteneurisation (Docker) et orchestration (Kubernetes) envisagées pour la scalabilité et la gestion des déploiements.

---

## 7. Métriques de Succès (KPIs)

* **Trafic Utilisateur :** Nombre d'utilisateurs uniques, d'utilisateurs actifs mensuels (MAU).
* **Engagement :** Nombre de sessions par utilisateur, durée moyenne des sessions, nombre d'offres consultées, nombre d'offres mises en favoris, nombre de candidatures lancées.
* **Taux de Conversion :** Taux d'inscription, taux de complétion de profil.
* **Qualité du Matching :** Taux de clics sur les offres "matchées", feedback utilisateur sur la pertinence des suggestions.
* **Performance Technique :** Temps de réponse moyens, uptime, taux d'erreurs API.

---

## 8. Feuille de Route et Phases de Développement

La feuille de route détaillée est disponible dans le document : `docs/ROADMAP.md`. Elle décrit la progression du projet par phases (MVP, Phase 2, Phase 3+) avec les fonctionnalités et intégrations API correspondantes.

---

## 9. Risques et Hypothèses

### 9.1. Risques

* **Dépendance APIs Externes :** Modification des APIs France Travail, latence ou indisponibilité.
* **Complexité de l'IA :** Difficulté à obtenir un matching de très haute qualité ou à interpréter les données de manière pertinente pour l'utilisateur.
* **Adoption Utilisateur :** Faible adoption si l'expérience ne répond pas aux attentes ou si la concurrence est trop forte.
* **Délai d'Obtention SSO France Travail :** Processus d'approbation long pouvant retarder des fonctionnalités clés de la Phase 2.
* **Coûts :** Coûts d'infrastructure et de développement plus élevés que prévu.

### 9.2. Hypothèses

* Les APIs France Travail resteront stables et documentées.
* Le processus d'obtention de l'accès SSO France Travail sera achevé dans un délai raisonnable.
* Une équipe de développement qualifiée sera disponible pour la durée du projet.
* Le budget alloué permettra de couvrir les coûts d'infrastructure et de développement.

---