# Feuille de Route Détaillée JobIA

Cette feuille de route présente une vision stratégique et progressive du développement de JobIA, depuis la préparation initiale jusqu'à un écosystème complet et intelligent, en s'appuyant sur les APIs identifiées et les principes de design inspirés de Google Careers.

---

## Vision Générale du Produit

**Mission :** Faciliter et personnaliser la recherche d'emploi et l'évolution professionnelle en France grâce à une plateforme intelligente, intuitive et basée sur les données officielles du marché du travail.

**Objectif Final :** Devenir la référence française pour l'accompagnement personnalisé des parcours professionnels, en offrant un matching IA avancé, des informations marché pertinentes et des conseils proactifs.

---

## Phases de Développement

---

### Phase 0 : Préparation & Lancement des Demandes (Jours 1-15)

* **Objectif :** Établir les bases techniques et administratives nécessaires au démarrage du développement, sécuriser les accès critiques.

* **Actions Clés :**
    * **Accès APIs France Travail (Client Credentials) :**
        * Obtention des identifiants et clés pour toutes les APIs partenaires (Offres d'emploi, ROME x4, Romeo, La Bonne Boîte, Marché du travail, Sortants de formation, Open Formation, Mes évènements).
        * Configuration et test des premières requêtes d'authentification pour confirmer l'accès.
    * **Demande API SSO France Travail :**
        * Identification du formulaire ou du processus de demande spécifique à l'API de connexion/authentification utilisateur de France Travail.
        * Préparation et soumission de la demande.
        * Suivi actif de l'état d'avancement de la demande.
    * **Mise en place de l'environnement de développement :**
        * Choix de la stack technique initiale (langages, frameworks backend/frontend).
        * Configuration des dépôts de code (Git, GitHub/GitLab).
        * Mise en place d'un environnement de développement local et d'un environnement de staging initial.
    * **Architecture BDD Initiale :**
        * Conception du schéma de base de données pour les utilisateurs et la synchronisation des référentiels ROME (Métiers, Compétences).

* **APIs et Dépendances Externes :**
    * Toutes les APIs France Travail (demande d'accès).
    * Processus d'obtention de l'accès SSO France Travail (lancé en parallèle, délai incertain).

---

### Phase 1 : MVP (Minimum Viable Product) - (Mois 1-3)

* **Objectif :** Lancer une version fonctionnelle de base de JobIA, permettant la recherche d'offres d'emploi et un matching IA simple, afin de valider l'intérêt et l'expérience utilisateur de base.

* **Fonctionnalités Clés du MVP :**

    * **Gestion Utilisateur :**
        * **Inscription/Connexion :** Système d'authentification propre à JobIA (email/mot de passe).
        * **Profil Utilisateur Basique :**
            * Informations personnelles (nom, prénom, contact, localisation).
            * Métier recherché (saisie texte libre, avec aide à la complétion via `Romeo`).
            * Compétences clés (saisie texte libre, avec aide à la complétion via `Romeo`).
    * **Recherche d'Offres d'Emploi :**
        * **Barre de Recherche Intuitive :** Recherche par mot-clé et localisation (inspirée de Google Careers).
        * **Filtres Simples :** Type de contrat, date de publication, rayon de recherche.
        * **Affichage des Résultats :** Liste paginée des offres avec informations clés (titre, entreprise, lieu, date).
    * **Matching IA Basique :**
        * **Analyse des Offres :** Utilisation de l'API `Romeo` pour extraire automatiquement les `Appellations ROME` (métiers) et les `Savoirs/Savoir-faire ROME` (compétences) à partir des descriptions d'offres. Stockage de ces mappings.
        * **Calcul de Pertinence :** Comparaison simple entre les compétences et métiers ROME du profil utilisateur et ceux extraits des offres. Affichage d'un score de matching simple ou mise en avant des offres "les plus pertinentes".
    * **Détail d'une Offre d'Emploi :**
        * Affichage complet de la description de l'offre.
        * Informations contextuelles (localisation, type de contrat, salaire si disponible).
        * Mise en évidence des compétences et métiers ROME extraits par l'IA.
    * **Actions sur les Offres :**
        * **Ajout aux Favoris :** Possibilité pour l'utilisateur de sauvegarder des offres.
        * **Candidature :** Redirection simple vers la page de candidature externe (URL de l'offre France Travail).
        * **Génération de Lettre de Motivation (Modèle Simple) :** Permet à l'utilisateur de générer une lettre de motivation basique, en s'appuyant sur les informations de l'offre et les infos de son profil JobIA.

* **Intégrations APIs Prioritaires pour le MVP :**
    1.  **`Offres d'emploi` (France Travail) :**
        * **Rôle :** Alimenter le moteur de recherche et l'affichage des annonces.
        * **Utilisation :** Appels dynamiques pour la recherche, récupération des détails d'offres spécifiques.
    2.  **`ROME 4.0 - Métiers` (France Travail) :**
        * **Rôle :** Référentiel structuré des métiers.
        * **Utilisation :** Synchronisation initiale et complète dans la BDD de JobIA. Utilisé pour la validation des métiers et l'interprétation des codes ROME renvoyés par Romeo.
    3.  **`ROME 4.0 - Compétences` (France Travail) :**
        * **Rôle :** Référentiel structuré des compétences (savoirs, savoir-faire, savoir-être).
        * **Utilisation :** Synchronisation initiale et complète dans la BDD de JobIA. Utilisé pour la validation des compétences et l'interprétation des codes ROME renvoyés par Romeo.
    4.  **`Romeo` (France Travail) :**
        * **Rôle :** Moteur d'IA pour le mapping texte libre <-> ROME.
        * **Utilisation :** Appels dynamiques pour analyser les descriptions d'offres d'emploi. Potentiellement pour aider à la complétion du profil utilisateur (métiers/compétences).

* **Considérations Techniques Spécifiques au MVP :**
    * **Backend :** Langage/Framework choisi (ex: Python/Django, Node.js/Express, Java/Spring Boot). Base de données relationnelle (PostgreSQL recommandé pour sa robustesse et sa flexibilité). Mise en place des services d'intégration pour la synchronisation ROME.
    * **Frontend :** Framework UI/UX (ex: React, Vue.js, Angular) avec un focus sur les principes de design Google Careers (simplicité, clarté).
    * **Déploiement :** Environnement Cloud de base (ex: quelques VMs, services managés pour BDD), avec un pipeline CI/CD simple.

---

### Phase 2 : Enrichissement & Personnalisation Approfondie (Mois 4-8)

* **Objectif :** Passer d'une plateforme de recherche "simple" à un assistant intelligent, en améliorant la personnalisation, la pertinence du matching et en offrant des informations stratégiques.

* **Fonctionnalités Clés :**

    * **Authentification Utilisateur Améliorée :**
        * **Intégration SSO France Travail :** Permettre aux utilisateurs de se connecter via leurs identifiants France Travail, avec gestion des consentements.
    * **Profil Utilisateur Avancé :**
        * **Analyse de CV :** Téléchargement de CV (PDF/DOCX) et extraction automatique des métiers et compétences ROME via l'API `Romeo`.
        * **Visualisation des Compétences :** Affichage interactif des compétences ROME maîtrisées et à développer.
        * **Préférences de Contexte de Travail :** Ajout de préférences utilisateur basées sur le référentiel `ROME V4.0 - Situations de travail`.
    * **Matching IA Avancé :**
        * **Intégration Soft Skills :** Utilisation de l'API `Match via Soft Skills` pour affiner le matching en prenant en compte les qualités professionnelles.
        * **Prise en compte des Situations de Travail :** Le matching intègre les préférences de l'utilisateur pour les environnements de travail.
        * **Explication du Matching :** L'IA explique pourquoi une offre est pertinente pour un utilisateur (ex: "Vous matchez à 85% sur les compétences techniques, et 70% sur les savoir-être").
    * **Informations Marché Stratégiques :**
        * **Tableaux de Bord Métier/Territoire :** Visualisation des données clés (métiers en tension, nombre de demandeurs d'emploi, volume d'offres) via l'API `Marché du travail`.
        * **Conseils de Candidature Spontanée :** Recommandation d'entreprises ayant un fort potentiel de recrutement dans un métier ou secteur donné (`La Bonne Boîte`).
    * **Orientation et Formation :**
        * **Suggestions de Formations Personnalisées :** Basées sur les compétences manquantes pour un métier cible, via l'API `Open formation`.
        * **Statistiques de Retour à l'Emploi après Formation :** Affichage des taux d'accès à l'emploi des sortants de formations pertinentes (`Sortants de formation et accès à l'emploi`).
    * **Exploration des Métiers :**
        * **Pages "Fiche Métier" Détaillées :** Utilisation de l'API `ROME V4.0 - Fiches ROME` pour présenter une vue complète d'un métier (définition, compétences clés, savoirs, contextes de travail, métiers proches).
        * **Parcours de Carrière :** Suggestions de progression ou de reconversion basées sur les similitudes ROME.
    * **Génération de Contenu Avancée :** Personnalisation plus poussée de la lettre de motivation et du CV, en intégrant les éléments issus de l'analyse ROME du profil et de l'offre.

* **Intégrations APIs Prioritaires pour la Phase 2 :**
    1.  **API SSO France Travail :** (Si l'accès est obtenu) Permet une connexion fluide et l'accès potentiel à des données de profil France Travail.
    2.  **`Match via Soft Skills` (Instarlink) :**
        * **Rôle :** Intégration des qualités professionnelles pour un matching plus humain.
        * **Utilisation :** Appels dynamiques pour évaluer la correspondance des soft skills entre profil et offre.
    3.  **`ROME V4.0 - Situations de travail` (France Travail) :**
        * **Rôle :** Référentiel des environnements de travail.
        * **Utilisation :** Synchronisation initiale. Permet aux utilisateurs de définir leurs préférences et d'affiner le matching.
    4.  **`ROME V4.0 - Fiches ROME` (France Travail) :**
        * **Rôle :** Fiches métiers agrégées et prêtes à l'emploi.
        * **Utilisation :** Appels à la demande pour afficher les pages détaillées des métiers.
    5.  **`La Bonne Boîte` (France Travail) :**
        * **Rôle :** Identifier les entreprises qui recrutent.
        * **Utilisation :** Appels dynamiques pour cibler les candidatures spontanées.
    6.  **`Marché du travail` (France Travail) :**
        * **Rôle :** Statistiques sur l'emploi, les métiers en tension.
        * **Utilisation :** Appels dynamiques pour alimenter des dashboards et des conseils marché.
    7.  **`Open formation` (France Travail) :**
        * **Rôle :** Offres de formation.
        * **Utilisation :** Appels dynamiques pour suggérer des formations.
    8.  **`Sortants de formation et accès à l'emploi` (France Travail) :**
        * **Rôle :** Statistiques sur le succès des formations.
        * **Utilisation :** Appels dynamiques pour valider la pertinence des formations.

* **Considérations Techniques Spécifiques à la Phase 2 :**
    * **Scalabilité :** Préparation à l'augmentation du nombre d'utilisateurs et de requêtes IA.
    * **Micro-services :** Possibilité de découper le backend en micro-services pour gérer la complexité croissante (ex: service de matching, service de profil, service de synchronisation ROME).
    * **Gestion des Données Utilisateur :** Implémentation stricte des règles RGPD pour les données sensibles issues du SSO et de l'analyse de CV.
    * **Cache Avancé :** Stratégies de caching plus agressives pour les données peu changeantes (référentiels, fiches ROME).
    * **Monitoring & Alerting :** Mise en place d'outils de surveillance des performances et de la fiabilité des APIs et des services internes.

---

### Phase 3 et au-delà : Excellence Opérationnelle & Expansion (Mois 9+)

* **Objectif :** Consolider la position de JobIA, optimiser la performance, explorer de nouvelles opportunités et fonctionnalités.

* **Fonctionnalités Clés :**

    * **Accompagnement Proactif :**
        * **`Mes évènements France Travail` :** Notifications et suggestions personnalisées d'événements (salons, ateliers) basées sur le profil et les intérêts de l'utilisateur.
        * **Recommandations proactives :** L'IA suggère des actions (formations, événements, mises à jour de profil) de manière non sollicitée mais pertinente.
    * **Amélioration Continue de l'IA :**
        * **Boucles de Feedback Utilisateur :** Exploitation des APIs de feedback de `Romeo` (`/performancePredictionCompetences`, etc.) pour améliorer l'IA.
        * **Apprentissage Personnalisé :** L'IA adapte ses recommandations en fonction des interactions et des succès/échecs de l'utilisateur.
    * **Outils d'Aide à la Négociation :** Basés sur les données du marché du travail (`Marché du travail`).
    * **Partenariats et Écosystème :** Intégration avec d'autres services ou plateformes (ex: plateformes de micro-learning, simulateurs d'entretien).
    * **Tableaux de bord personnalisés pour le suivi de la progression.**

* **Intégrations APIs :**
    * **`Mes évènements France Travail` :**
        * **Rôle :** Accès aux événements liés à l'emploi.
        * **Utilisation :** Appels dynamiques pour afficher les événements pertinents.
    * Optimisation de l'utilisation de toutes les APIs existantes.
    * Exploration de nouvelles APIs France Travail ou partenaires.

* **Considérations Techniques :**
    * Optimisation des coûts d'infrastructure.
    * Approfondissement des stratégies d'IA (machine learning, traitement du langage naturel) pour des fonctionnalités plus complexes.
    * Amélioration de la résilience et de la gestion des pannes.